powered by
Makes a query to the Canadian Nutrient File food endpoint. This endpoint returns data from a list of food codes and corresponding names.
get_food(apiKey = NULL, foodCode = NULL, lang = "en")
Key to access the API. Can be retrieved from https://hc-sc.api.canada.ca/en/detail?api=cnf#!/Nutrient/get_nutrientamount. If none is provided, the system environment variables will be checked.
The code indicating the food you want to search for. If null, all foods are returned.
The language to return results in, can be either 'en' or 'fr'.
A tibble containing food names and food ids.
# NOT RUN { get_food() get_food(foodCode = 2314) get_food(foodcode = 2314, lang = "fr") # }
Run the code above in your browser using DataLab